Module error

Module error 

Modules

callsite_fns

Structs

CoreError
CoreModuleExecuteError
CoreModuleParseError
CreateCodeCacheError
DataError
ExtensionLazyInitCountMismatchError
ExtensionLazyInitOrderMismatchError
ExtensionSnapshotMismatchError
FileNameParts
InitialCwd
JsError
A JsError represents an exception coming from V8, with stack frames and line numbers. The deno_cli crate defines another JsError type, which wraps the one defined here, that adds source map support and colorful formatting. When updating this struct, also update errors_are_equal_without_cause() in fmt_error.rs.
JsStackFrame
NoAnsiColors
Formats an error without using ansi colors.

Enums

CoreErrorKind
ErrorElement
Part of an error stack trace
ModuleConcreteError
ResourceError

Statics

ERROR
ERROR_RECEIVER_IS_NOT_VALID_CALLSITE_OBJECT
GET_COLUMN_NUMBER
GET_EVAL_ORIGIN
GET_FILE_NAME
GET_FUNCTION
GET_FUNCTION_NAME
GET_LINE_NUMBER
GET_METHOD_NAME
GET_PROMISE_INDEX
GET_SCRIPT_NAME_OR_SOURCE_URL
GET_THIS
GET_TYPE_NAME
IS_ASYNC
IS_CONSTRUCTOR
IS_EVAL
IS_NATIVE
IS_PROMISE_ALL
IS_TOPLEVEL
ORIGINAL
PREPARE_STACK_TRACE
SOURCE_MAPPED_INFO
TO_STRING

Traits

ErrorFormat
Applies formatting to various parts of error stack traces.

Functions

dispatch_exception
Effectively throw an uncatchable error. This will terminate runtime execution before any more JS code can run, except in the REPL where it should just output the error to the console.
exception_to_err
format_file_name
format_frame
format_location
format_stack_trace
prepare_stack_trace_callback
Callback to prepare an error stack trace. This callback is invoked by V8 whenever a stack trace is created. This will patch callsite objects to translate file URLs to file paths before they’re exposed to user-defined prepareStackTrace implementations.
prepare_stack_trace_callback_with_original_callsites
Callback to prepare an error stack trace. This callback is invoked by V8 whenever a stack trace is created. This will patch callsite objects to translate file URLs to file paths before they’re exposed to user-defined prepareStackTrace implementations.
relative_specifier
throw_error_js_error_class
throw_error_one_byte
throw_error_one_byte_info
throw_invalid_this_error_one_byte
throw_invalid_this_error_one_byte_info
Throw a Node-flavoured ERR_INVALID_THIS TypeError – a plain TypeError whose code own-property is "ERR_INVALID_THIS". The op2 macro uses this to report cppgc brand-check failures so that the thrown error matches the webidl.assertBranded shape expected by web platform and Node compat tests.
throw_js_error_class
to_v8_error

Type Aliases

AnyError
A generic wrapper that can encapsulate any concrete error type.
ModuleLoaderError