Modules
Structs
- Core
Error - Core
Module Execute Error - Core
Module Parse Error - Create
Code Cache Error - Data
Error - Extension
Lazy Init Count Mismatch Error - Extension
Lazy Init Order Mismatch Error - Extension
Snapshot Mismatch Error - File
Name Parts - Initial
Cwd - JsError
- A
JsErrorrepresents an exception coming from V8, with stack frames and line numbers. The deno_cli crate defines anotherJsErrortype, which wraps the one defined here, that adds source map support and colorful formatting. When updating this struct, also update errors_are_equal_without_cause() in fmt_error.rs. - JsStack
Frame - NoAnsi
Colors - Formats an error without using ansi colors.
Enums
- Core
Error Kind - Error
Element - Part of an error stack trace
- Module
Concrete Error - Resource
Error
Statics
- ERROR
- ERROR_
RECEIVER_ IS_ NOT_ VALID_ CALLSITE_ OBJECT - GET_
COLUMN_ NUMBER - GET_
EVAL_ ORIGIN - GET_
FILE_ NAME - GET_
FUNCTION - GET_
FUNCTION_ NAME - GET_
LINE_ NUMBER - GET_
METHOD_ NAME - GET_
PROMISE_ INDEX - GET_
SCRIPT_ NAME_ OR_ SOURCE_ URL - GET_
THIS - GET_
TYPE_ NAME - IS_
ASYNC - IS_
CONSTRUCTOR - IS_EVAL
- IS_
NATIVE - IS_
PROMISE_ ALL - IS_
TOPLEVEL - ORIGINAL
- PREPARE_
STACK_ TRACE - SOURCE_
MAPPED_ INFO - TO_
STRING
Traits
- Error
Format - Applies formatting to various parts of error stack traces.
Functions
- dispatch_
exception - Effectively throw an uncatchable error. This will terminate runtime execution before any more JS code can run, except in the REPL where it should just output the error to the console.
- exception_
to_ err - format_
file_ name - format_
frame - format_
location - format_
stack_ trace - prepare_
stack_ trace_ callback - Callback to prepare an error stack trace. This callback is invoked by V8 whenever a stack trace is created.
This will patch callsite objects to translate file URLs to file paths before they’re
exposed to user-defined
prepareStackTraceimplementations. - prepare_
stack_ trace_ callback_ with_ original_ callsites - Callback to prepare an error stack trace. This callback is invoked by V8 whenever a stack trace is created.
This will patch callsite objects to translate file URLs to file paths before they’re
exposed to user-defined
prepareStackTraceimplementations. - relative_
specifier - throw_
error_ js_ error_ class - throw_
error_ one_ byte - throw_
error_ one_ byte_ info - throw_
invalid_ this_ error_ one_ byte - throw_
invalid_ this_ error_ one_ byte_ info - Throw a Node-flavoured
ERR_INVALID_THISTypeError– a plainTypeErrorwhosecodeown-property is"ERR_INVALID_THIS". The op2 macro uses this to report cppgc brand-check failures so that the thrown error matches thewebidl.assertBrandedshape expected by web platform and Node compat tests. - throw_
js_ error_ class - to_
v8_ error
Type Aliases
- AnyError
- A generic wrapper that can encapsulate any concrete error type.
- Module
Loader Error